pub type ClientReceiver = UnboundedReceiver<String>;Expand description
Handle for receiving messages from the hub to send to WebSocket.
Aliased Type
pub struct ClientReceiver { /* private fields */ }pub type ClientReceiver = UnboundedReceiver<String>;Handle for receiving messages from the hub to send to WebSocket.
pub struct ClientReceiver { /* private fields */ }